@@ -16,9 +16,10 @@ import colorcet as cc
 import scanpy as sc
 #from new_func import new_layout
 # from main3 import change_class_color
-from transform import data_trans
+
 import os, sys
 import importlib
+from bokeh.server.server import Server
 
 
 
@@ -230,11 +231,13 @@ class FlowPlot:
             self.marker_file.on_change('filename', lambda attr, old, new: self.marker_choice())
             self.cell_type = Select(title='Choose Cell Type:', options=['No cell type'], value='No cell type')
             self.cell_type.on_change('value',lambda attr, old, new: self.change_marker_ct())
-            
+            self.ct_marker = Select(title='Choose marker of the celltype', options=['Cell type not chosen'], value='Cell type not chosen')
+            self.show_marker = Button(label='Show Marker Gene Expression')
+            self.show_marker.on_click(lambda: self.show_colorbar(marker=True))
             self.hl_input = AutocompleteInput(completions=list(self.adata.var.index), title="Select Highlight Gene: ", min_characters=1)
             # Show Highlight Gene
             self.hl_button = Button(label="Show Highlight Gene")
-            self.hl_button.on_click(self.show_colorbar)
+            self.hl_button.on_click(lambda: self.show_colorbar(marker=False))
             # Filt cells according to gene expression
             self.hl_filt = Select(options=['Gene Expression >','Gene Expression =','Gene Expression <'],value='Gene Expression >')
             self.hl_filt_num = TextInput()
@@ -588,8 +591,11 @@ class FlowPlot:
         #print(hide.value,now_color)
 
     #### Highly variable gene functions #####
-    def show_colorbar(self):
-        updated_color = self.data_df.loc[:,self.hl_input.value]
+    def show_colorbar(self, marker):
+        if marker:
+            updated_color = self.data_df.loc[:,self.ct_marker.value]
+        else:
+            updated_color = self.data_df.loc[:,self.hl_input.value]
         updated_color = (updated_color-min(updated_color))*(self.hl_bar_map.high - self.hl_bar_map.low)/(max(updated_color)-min(updated_color))
         self.source.data["hl_gene"] = list(updated_color) 
     
@@ -614,7 +620,7 @@ class FlowPlot:
     def marker_choice(self):
         print('filename change: ',self.marker_file.filename)
         if True:
-            marker = pandas.read_csv('~/.local/scpantheon-dir/data/' + self.marker_file.filename)
+            marker = pandas.read_csv('data/' + self.marker_file.filename)
 
             cell_type = list(set(marker['cell_type']))
             print(cell_type)
@@ -629,18 +635,12 @@ class FlowPlot:
 
     def change_marker_ct(self):
         cell_type = self.cell_type.value
-        marker = pandas.read_csv('~/.local/scpantheon-dir/data/' + self.marker_file.filename)
+        marker = pandas.read_csv('data/' + self.marker_file.filename)
         print('+++++++marker gene')
-        #cell_type = list(set(marker['cell_type']))
-        if cell_type == 'No cell type':
-            self.hl_input.completions = list(self.adata.var.index)
-            self.hl_input.title="Select Highlight Gene: "
-            #self.hl_input = AutocompleteInput(completions=list(self.adata.var.index), title="Select Highlight Gene: ", min_characters=1)
-        else:
-            marker_list = list(marker[marker['cell_type']==cell_type].loc[:,'marker_gene'])
-            print(marker_list)
-            self.hl_input.completions = marker_list
-            self.hl_input.title="Select the Marker Gene:"
+        marker_list = list(marker[marker['cell_type']==cell_type].loc[:,'marker_gene'])
+        self.ct_marker.options = marker_list
+        self.ct_marker.value = marker_list[0]
+
 
     def change_select(self, main_plot):
         main_plot.source.selected.indices = self.source.selected.indices
@@ -667,6 +667,23 @@ class FlowPlot:
             col_list = [color if j in inds else col_list[j] for j in range(len(col_list))] 
         self.source.data['color'] = col_list
 
+class data_trans():
+    def __init__(self,
+                 x_label,
+                 data_color,
+                 selected_color,
+                 checked_class,
+                 selected_group,
+                 selected_indices,
+                 showing_indices
+                 ):
+        self.data_color = data_color
+        self.x_label = x_label
+        self.selected_color = selected_color
+        self.checked_class = checked_class
+        self.selected_group = selected_group
+        self.selected_indices = selected_indices
+        self.showing_indices = showing_indices
 
 
 
@@ -700,7 +717,7 @@ class CreateTool:
         #hl_figure.p.visible = False
         #hl_figure.marker_choice()
         layout = row(hl_figure.p,
-                 column(hl_figure.marker_file, hl_figure.cell_type, hl_figure.hl_input, hl_figure.hl_button, 
+                 column(hl_figure.marker_file, hl_figure.cell_type, hl_figure.ct_marker, hl_figure.show_marker, hl_figure.hl_input, hl_figure.hl_button, 
                  row(hl_figure.hl_filt, hl_figure.hl_filt_num),hl_figure.hl_filt_button,hl_figure.hl_comfirm))
         return hl_figure, layout
 
@@ -876,12 +893,22 @@ class plot_function:
 #     curdoc().add_root(buttons)
 
 def load_options():
-    name_list = os.listdir('extension')
+    try:
+        path = os.path.split(os.path.abspath(__file__))[0]
+        print(path)
+        name_list = os.listdir(path+'/extension')
+    except:
+        name_list = []
     return name_list
     
+    
 def load_module(active):
     buttons = curdoc().get_model_by_name('module_buttons')
-    name_list = os.listdir('extension')
+    try:
+        path = os.path.split(os.path.abspath(__file__))[0]
+        name_list = os.listdir(path+'/extension')
+    except:
+        return 
     layouts = column()
     print('active',active)
     ind = 0
@@ -945,46 +972,48 @@ def upload_callback(upload_button):
     #loading_remind = Div(text='<img src="./images/loading.gif" alt='' />')
     curdoc().add_root(loading_remind)
     print('===loading finifshed=====')
+    path = os.path.split(__file__)[0]
     def load():
         global Main_plot
         filetype = os.path.splitext(upload_button.filename)[-1][1:]
         if filetype == 'csv':
-            adata = anndata.read_csv('~/.local/scpantheon-dir/data/'+upload_button.filename)
+            adata = anndata.read_csv(path+'/data/'+upload_button.filename)
             print('csv')
         elif filetype == 'h5ad':
-            adata = anndata.read('~/.local/scpantheon-dir/data/'+upload_button.filename)
+            adata = anndata.read(path+'/data/'+upload_button.filename)
             print('h5ad')
         elif filetype == 'mtx':
             adata = sc.read_10x_mtx(
-                '~/.local/scpantheon-dir/data/hg19/',  # the directory with the `.mtx` file
+                'data/hg19/',  # the directory with the `.mtx` file
                 var_names='gene_symbols',                # use gene symbols for the variable names (variables-axis index)
                 cache=True)                              # write a cache file for faster subsequent reading
         print(upload_button.filename)
         mainplot, panel1 = CreateTool(adata=adata).base_tool()
         print('===mainplot finifshed=====')
         Main_plot = mainplot
-        print(Main_plot)
         hl_figure, panel2 = CreateTool(adata=adata).highlight_gene(mainplot)
         print('====highlight finished=====')
         tab = CreateTool(adata).multi_panel([mainplot,hl_figure],[panel1,panel2], ['Main View', 'Highlight Gene'], update_view=True)
         print('====tab====')
         curdoc().remove_root(loading_remind)
         curdoc().add_root(tab)
+    
 
     curdoc().add_next_tick_callback(load)
+    
 
 
     
 
 
-def main():
+def main(doc):
+    global Main_plot
     upload_button = FileInput()
     upload_button.on_change('filename',lambda attr, old, new: upload_callback(upload_button))
     
-    curdoc().add_root(upload_button)
+    doc.add_root(upload_button)
     
 
 
-
 if __name__ == "main":
     main()
